@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,6 +32,7 @@
 #include <config.h>
 #endif
 
+#include <libintl.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -404,6 +405,8 @@ get_data_boxed_fn( guint type )
  * @def: a #NADataDef definition structure.
  *
  * Returns: a #GParamSpec structure.
+ *
+ * Since: 2.30
  */
 GParamSpec *
 na_data_boxed_get_param_spec( const NADataDef *def )
@@ -430,6 +433,8 @@ na_data_boxed_get_param_spec( const NADataDef *def )
  * @def: the #NADataDef definition structure for this boxed.
  *
  * Returns: a newly allocated #NADataBoxed.
+ *
+ * Since: 2.30
  */
 NADataBoxed *
 na_data_boxed_new( const NADataDef *def )
@@ -451,6 +456,8 @@ na_data_boxed_new( const NADataDef *def )
  *
  * Returns: a pointer to the #NADataDef structure attached to the object.
  * Should never be %NULL.
+ *
+ * Since: 2.30
  */
 NADataDef *
 na_data_boxed_get_data_def( const NADataBoxed *boxed )
@@ -475,6 +482,8 @@ na_data_boxed_get_data_def( const NADataBoxed *boxed )
  * @b: the second #NADataBoxed object.
  *
  * Returns: %TRUE if the two boxeds are equal, %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_data_boxed_are_equal( const NADataBoxed *a, const NADataBoxed *b )
@@ -511,6 +520,8 @@ na_data_boxed_are_equal( const NADataBoxed *a, const NADataBoxed *b )
  *
  * Returns: %TRUE if the #NADataBoxed holds its default value,
  * %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_data_boxed_is_default( const NADataBoxed *boxed )
@@ -541,6 +552,8 @@ na_data_boxed_is_default( const NADataBoxed *boxed )
  * @boxed: the #NADataBoxed object whose validity is to be checked.
  *
  * Returns: %TRUE if the boxed is valid, %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_data_boxed_is_valid( const NADataBoxed *boxed )
@@ -571,6 +584,8 @@ na_data_boxed_is_valid( const NADataBoxed *boxed )
  * @boxed: this #NADataBoxed object.
  *
  * Dump the content of @boxed.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_dump( const NADataBoxed *boxed )
@@ -594,6 +609,8 @@ na_data_boxed_dump( const NADataBoxed *boxed )
  * Changes the #NADataDef a @boxed points to:
  * -> the new type must be the same that the previous one.
  * -> value is unchanged.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_set_data_def( NADataBoxed *boxed, const NADataDef *new_def )
@@ -614,6 +631,8 @@ na_data_boxed_set_data_def( NADataBoxed *boxed, const NADataDef *new_def )
  *
  * Returns: the value of the @boxed, as a newly allocated string which
  * should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_data_boxed_get_as_string( const NADataBoxed *boxed )
@@ -648,6 +667,8 @@ na_data_boxed_get_as_string( const NADataBoxed *boxed )
  * If of type NAFD_TYPE_STRING, NAFD_TYPE_LOCALE_STRING OR
  * NAFD_TYPE_STRING_LIST, then the content is returned in a newly
  * allocated value, which should be released by the caller.
+ *
+ * Since: 2.30
  */
 void *
 na_data_boxed_get_as_void( const NADataBoxed *boxed )
@@ -679,6 +700,8 @@ na_data_boxed_get_as_void( const NADataBoxed *boxed )
  * @value: the string to be set.
  *
  * Setup @value with the content of the @boxed.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_get_as_value( const NADataBoxed *boxed, GValue *value )
@@ -705,6 +728,8 @@ na_data_boxed_get_as_value( const NADataBoxed *boxed, GValue *value )
  * @value: the source #NADataBoxed.
  *
  * Copy value from @value to @boxed.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_set_from_boxed( NADataBoxed *boxed, const NADataBoxed *value )
@@ -736,6 +761,8 @@ na_data_boxed_set_from_boxed( NADataBoxed *boxed, const NADataBoxed *value )
  * @value: the string to be set.
  *
  * Evaluates the @value and set it to the @boxed.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_set_from_string( NADataBoxed *boxed, const gchar *value )
@@ -765,6 +792,8 @@ na_data_boxed_set_from_string( NADataBoxed *boxed, const gchar *value )
  * @value: the value whose content is to be got.
  *
  * Evaluates the @value and set it to the @boxed.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_set_from_value( NADataBoxed *boxed, const GValue *value )
@@ -794,6 +823,8 @@ na_data_boxed_set_from_value( NADataBoxed *boxed, const GValue *value )
  * @value: the value whose content is to be got.
  *
  * Evaluates the @value and set it to the @boxed.
+ *
+ * Since: 2.30
  */
 void
 na_data_boxed_set_from_void( NADataBoxed *boxed, const void *value )
@@ -822,8 +853,8 @@ string_spec( const NADataDef *def )
 {
 	return( g_param_spec_string(
 			def->name,
-			def->short_label,
-			def->long_label,
+			gettext( def->short_label ),
+			gettext( def->long_label ),
 			def->default_value,
 			G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 }
@@ -1011,8 +1042,8 @@ slist_spec( const NADataDef *def )
 {
 	return( g_param_spec_pointer(
 			def->name,
-			def->short_label,
-			def->long_label,
+			gettext( def->short_label ),
+			gettext( def->long_label ),
 			G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 }
 
@@ -1155,8 +1186,8 @@ bool_spec( const NADataDef *def )
 {
 	return( g_param_spec_boolean(
 			def->name,
-			def->short_label,
-			def->long_label,
+			gettext( def->short_label ),
+			gettext( def->long_label ),
 			na_core_utils_boolean_from_string( def->default_value ),
 			G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 }
@@ -1247,8 +1278,8 @@ pointer_spec( const NADataDef *def )
 {
 	return( g_param_spec_pointer(
 			def->name,
-			def->short_label,
-			def->long_label,
+			gettext( def->short_label ),
+			gettext( def->long_label ),
 			G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 }
 
@@ -1343,8 +1374,8 @@ uint_spec( const NADataDef *def )
 {
 	return( g_param_spec_uint(
 			def->name,
-			def->short_label,
-			def->long_label,
+			gettext( def->short_label ),
+			gettext( def->long_label ),
 			0,
 			UINT_MAX,
 			atoi( def->default_value ),
@@ -1417,7 +1448,7 @@ uint_set_from_boxed( NADataBoxed *boxed, const NADataBoxed *source )
 static void
 uint_set_from_string( NADataBoxed *boxed, const gchar *string )
 {
-	boxed->private->u.uint = atoi( string );
+	boxed->private->u.uint = string ? atoi( string ) : 0;
 }
 
 static void
