@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -88,7 +88,7 @@ static void   dump( const NAIOProvider *provider );
 
 static GList *get_merged_items_list( const NAPivot *pivot, GList *providers, GSList **messages );
 static GList *build_hierarchy( GList **tree, GSList *level_zero, gboolean list_if_empty, NAObjectItem *parent );
-static gint   search_item( const NAObject *obj, const gchar *uuid );
+static gint   search_item( const NAObject *obj, const gchar *id );
 static GList *sort_tree( const NAPivot *pivot, GList *tree, GCompareFunc fn );
 static GList *filter_unwanted_items( const NAPivot *pivot, GList *merged );
 static GList *filter_unwanted_items_rec( GList *merged, gboolean load_disabled, gboolean load_invalid );
@@ -755,13 +755,13 @@ build_hierarchy( GList **tree, GSList *level_zero, gboolean list_if_empty, NAObj
 
 	if( g_slist_length( level_zero )){
 		for( ilevel = level_zero ; ilevel ; ilevel = ilevel->next ){
-			/*g_debug( "%s: uuid=%s", thisfn, ( gchar * ) ilevel->data );*/
+			/*g_debug( "%s: id=%s", thisfn, ( gchar * ) ilevel->data );*/
 			it = g_list_find_custom( *tree, ilevel->data, ( GCompareFunc ) search_item );
 			if( it ){
 				hierarchy = g_list_append( hierarchy, it->data );
 				na_object_set_parent( it->data, parent );
 
-				g_debug( "%s: uuid=%s: %s (%p) appended to hierarchy %p",
+				g_debug( "%s: id=%s: %s (%p) appended to hierarchy %p",
 						thisfn, ( gchar * ) ilevel->data, G_OBJECT_TYPE_NAME( it->data ), ( void * ) it->data, ( void * ) hierarchy );
 
 				*tree = g_list_remove_link( *tree, it );
@@ -791,17 +791,17 @@ build_hierarchy( GList **tree, GSList *level_zero, gboolean list_if_empty, NAObj
 }
 
 /*
- * returns zero when obj has the required uuid
+ * returns zero when obj has the required id
  */
 static gint
-search_item( const NAObject *obj, const gchar *uuid )
+search_item( const NAObject *obj, const gchar *id )
 {
 	gchar *obj_id;
 	gint ret = 1;
 
 	if( NA_IS_OBJECT_ITEM( obj )){
 		obj_id = na_object_get_id( obj );
-		ret = strcmp( obj_id, uuid );
+		ret = strcmp( obj_id, id );
 		g_free( obj_id );
 	}
 
@@ -1388,7 +1388,7 @@ na_io_provider_get_return_code_label( guint code )
 			break;
 
 		default:
-			label = g_strdup_printf( _( "Unknow return code (%d).\n" \
+			label = g_strdup_printf( _( "Unknown return code (%d).\n" \
 					"Please, be kind enough to fill out a bug report on http://bugzilla.gnome.org." ), code );
 			break;
 	}
