@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,32 +44,22 @@
 
 /* private class data
  */
-struct NATokensClassPrivate {
+struct _NATokensClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NATokensPrivate {
+struct _NATokensPrivate {
 	gboolean dispose_has_run;
-
 	guint    count;
-
 	GSList  *uris;
-	gchar   *uris_str;
 	GSList  *filenames;
-	gchar   *filenames_str;
 	GSList  *basedirs;
-	gchar   *basedirs_str;
 	GSList  *basenames;
-	gchar   *basenames_str;
 	GSList  *basenames_woext;
-	gchar   *basenames_woext_str;
 	GSList  *exts;
-	gchar   *exts_str;
 	GSList  *mimetypes;
-	gchar   *mimetypes_str;
-
 	gchar   *hostname;
 	gchar   *username;
 	guint    port;
@@ -84,10 +74,11 @@ static void      instance_init( GTypeInstance *instance, gpointer klass );
 static void      instance_dispose( GObject *object );
 static void      instance_finalize( GObject *object );
 
-static NATokens *build_string_lists( NATokens *tokens );
-static void      execute_action_command( const gchar *command, const NAObjectProfile *profile );
+static void      execute_action_command( gchar *command, const NAObjectProfile *profile );
 static gboolean  is_singular_exec( const NATokens *tokens, const gchar *exec );
-static gchar    *parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8 );
+static gchar    *parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8, gboolean quoted );
+static GString  *quote_string( GString *input, const gchar *name, gboolean quoted );
+static GString  *quote_string_list( GString *input, GSList *names, gboolean quoted );
 
 GType
 na_tokens_get_type( void )
@@ -158,20 +149,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	self->private = g_new0( NATokensPrivate, 1 );
 
 	self->private->uris = NULL;
-	self->private->uris_str = NULL;
 	self->private->filenames = NULL;
-	self->private->filenames_str = NULL;
 	self->private->basedirs = NULL;
-	self->private->basedirs_str = NULL;
 	self->private->basenames = NULL;
-	self->private->basenames_str = NULL;
 	self->private->basenames_woext = NULL;
-	self->private->basenames_woext_str = NULL;
 	self->private->exts = NULL;
-	self->private->exts_str = NULL;
 	self->private->mimetypes = NULL;
-	self->private->mimetypes_str = NULL;
-
 	self->private->hostname = NULL;
 	self->private->username = NULL;
 	self->private->port = 0;
@@ -215,20 +198,12 @@ instance_finalize( GObject *object )
 	g_free( self->private->scheme );
 	g_free( self->private->username );
 	g_free( self->private->hostname );
-
-	g_free( self->private->mimetypes_str );
 	na_core_utils_slist_free( self->private->mimetypes );
-	g_free( self->private->exts_str );
 	na_core_utils_slist_free( self->private->exts );
-	g_free( self->private->basenames_woext_str );
 	na_core_utils_slist_free( self->private->basenames_woext );
-	g_free( self->private->basenames_str );
 	na_core_utils_slist_free( self->private->basenames );
-	g_free( self->private->basedirs_str );
 	na_core_utils_slist_free( self->private->basedirs );
-	g_free( self->private->filenames_str );
 	na_core_utils_slist_free( self->private->filenames );
-	g_free( self->private->uris_str );
 	na_core_utils_slist_free( self->private->uris );
 
 	g_free( self->private );
@@ -239,7 +214,7 @@ instance_finalize( GObject *object )
 	}
 }
 
-/**
+/*
  * na_tokens_new_for_example:
  *
  * Returns: a new #NATokens object initialized with fake values for two
@@ -297,10 +272,10 @@ na_tokens_new_for_example( void )
 	tokens->private->username = g_strdup( ex_user );
 	tokens->private->port = ex_port;
 
-	return( build_string_lists( tokens ));
+	return( tokens );
 }
 
-/**
+/*
  * na_tokens_new_from_selection:
  * @selection: a #GList list of #NASelectedInfo objects.
  *
@@ -313,9 +288,7 @@ na_tokens_new_from_selection( GList *selection )
 	NATokens *tokens;
 	GList *it;
 	gchar *uri, *filename, *basedir, *basename, *bname_woext, *ext, *mimetype;
-	GFile *location;
 	gboolean first;
-	NAGnomeVFSURI *vfs;
 
 	g_debug( "%s: selection=%p (count=%d)", thisfn, ( void * ) selection, g_list_length( selection ));
 
@@ -325,60 +298,55 @@ na_tokens_new_from_selection( GList *selection )
 	tokens->private->count = g_list_length( selection );
 
 	for( it = selection ; it ; it = it->next ){
-		location = na_selected_info_get_location( NA_SELECTED_INFO( it->data ));
 		mimetype = na_selected_info_get_mime_type( NA_SELECTED_INFO( it->data ));
 
 		uri = na_selected_info_get_uri( NA_SELECTED_INFO( it->data ));
-		filename = g_file_get_path( location );
-		basedir = g_path_get_dirname( filename );
-		basename = g_file_get_basename( location );
+		filename = na_selected_info_get_path( NA_SELECTED_INFO( it->data ));
+		basedir = na_selected_info_get_dirname( NA_SELECTED_INFO( it->data ));
+		basename = na_selected_info_get_basename( NA_SELECTED_INFO( it->data ));
 		na_core_utils_dir_split_ext( basename, &bname_woext, &ext );
 
 		if( first ){
-			vfs = g_new0( NAGnomeVFSURI, 1 );
-			na_gnome_vfs_uri_parse( vfs, uri );
-
-			tokens->private->hostname = g_strdup( vfs->host_name );
-			tokens->private->username = g_strdup( vfs->user_name );
-			tokens->private->port = vfs->host_port;
-			tokens->private->scheme = g_strdup( vfs->scheme );
-
-			na_gnome_vfs_uri_free( vfs );
+			tokens->private->hostname = na_selected_info_get_uri_host( NA_SELECTED_INFO( it->data ));
+			tokens->private->username = na_selected_info_get_uri_user( NA_SELECTED_INFO( it->data ));
+			tokens->private->port = na_selected_info_get_uri_port( NA_SELECTED_INFO( it->data ));
+			tokens->private->scheme = na_selected_info_get_uri_scheme( NA_SELECTED_INFO( it->data ));
 			first = FALSE;
 		}
 
-		tokens->private->uris = g_slist_prepend( tokens->private->uris, uri );
-		tokens->private->filenames = g_slist_prepend( tokens->private->filenames, filename );
-		tokens->private->basedirs = g_slist_prepend( tokens->private->basedirs, basedir );
-		tokens->private->basenames = g_slist_prepend( tokens->private->basenames, basename );
-		tokens->private->basenames_woext = g_slist_prepend( tokens->private->basenames_woext, bname_woext );
-		tokens->private->exts = g_slist_prepend( tokens->private->exts, ext );
-		tokens->private->mimetypes = g_slist_prepend( tokens->private->mimetypes, mimetype );
-
-		g_object_unref( location );
+		tokens->private->uris = g_slist_append( tokens->private->uris, uri );
+		tokens->private->filenames = g_slist_append( tokens->private->filenames, filename );
+		tokens->private->basedirs = g_slist_append( tokens->private->basedirs, basedir );
+		tokens->private->basenames = g_slist_append( tokens->private->basenames, basename );
+		tokens->private->basenames_woext = g_slist_append( tokens->private->basenames_woext, bname_woext );
+		tokens->private->exts = g_slist_append( tokens->private->exts, ext );
+		tokens->private->mimetypes = g_slist_append( tokens->private->mimetypes, mimetype );
 	}
 
-	return( build_string_lists( tokens ));
+	return( tokens );
 }
 
-/**
- * na_tokens_parse_parameters:
+/*
+ * na_tokens_parse_for_display:
  * @tokens: a #NATokens object.
  * @string: the input string, may or may not contain tokens.
  * @utf8: whether the @input string is UTF-8 encoded, or a standard ASCII string.
  *
  * Expands the parameters in the given string.
  *
+ * This expanded string is meant to be displayed only (not executed) as
+ * filenames are not shell-quoted.
+ *
  * Returns: a copy of @input string with tokens expanded, as a newly
  * allocated string which should be g_free() by the caller.
  */
 gchar *
-na_tokens_parse_parameters( const NATokens *tokens, const gchar *string, gboolean utf8 )
+na_tokens_parse_for_display( const NATokens *tokens, const gchar *string, gboolean utf8 )
 {
-	return( parse_singular( tokens, string, 0, utf8 ));
+	return( parse_singular( tokens, string, 0, utf8, FALSE ));
 }
 
-/**
+/*
  * na_tokens_execute_action:
  * @tokens: a #NATokens object.
  * @profile: the #NAObjectProfile to be executed.
@@ -388,9 +356,10 @@ na_tokens_parse_parameters( const NATokens *tokens, const gchar *string, gboolea
 void
 na_tokens_execute_action( const NATokens *tokens, const NAObjectProfile *profile )
 {
-	gchar *path, *parameters, *exec, *command;
+	gchar *path, *parameters, *exec;
 	gboolean singular;
 	guint i;
+	gchar *command;
 
 	path = na_object_get_path( profile );
 	parameters = na_object_get_parameters( profile );
@@ -402,43 +371,59 @@ na_tokens_execute_action( const NATokens *tokens, const NAObjectProfile *profile
 
 	if( singular ){
 		for( i = 0 ; i < tokens->private->count ; ++i ){
-			command = parse_singular( tokens, exec, i, FALSE );
+			command = parse_singular( tokens, exec, i, FALSE, TRUE );
 			execute_action_command( command, profile );
 			g_free( command );
 		}
 
 	} else {
-		command = na_tokens_parse_parameters( tokens, exec, FALSE );
+		command = parse_singular( tokens, exec, 0, FALSE, TRUE );
 		execute_action_command( command, profile );
 		g_free( command );
 	}
 
-
 	g_free( exec );
 }
 
-static NATokens *
-build_string_lists( NATokens *tokens )
-{
-	tokens->private->uris_str = na_core_utils_slist_join_at_end( tokens->private->uris, " " );
-	tokens->private->filenames_str = na_core_utils_slist_join_at_end( tokens->private->filenames, " " );
-	tokens->private->basedirs_str = na_core_utils_slist_join_at_end( tokens->private->basedirs, " " );
-	tokens->private->basenames_str = na_core_utils_slist_join_at_end( tokens->private->basenames, " " );
-	tokens->private->basenames_woext_str = na_core_utils_slist_join_at_end( tokens->private->basenames_woext, " " );
-	tokens->private->exts_str = na_core_utils_slist_join_at_end( tokens->private->exts, " " );
-	tokens->private->mimetypes_str = na_core_utils_slist_join_at_end( tokens->private->mimetypes, " " );
-
-	return( tokens );
-}
-
 static void
-execute_action_command( const gchar *command, const NAObjectProfile *profile )
+execute_action_command( gchar *command, const NAObjectProfile *profile )
 {
 	static const gchar *thisfn = "nautilus_actions_execute_action_command";
+	GError *error;
+	gchar **argv;
+	gint argc;
+	gchar *wdir;
+	GPid child_pid;
 
 	g_debug( "%s: command=%s, profile=%p", thisfn, command, ( void * ) profile );
 
-	g_spawn_command_line_async( command, NULL );
+	error = NULL;
+
+	if( !g_shell_parse_argv( command, &argc, &argv, &error )){
+		g_warning( "%s: %s", thisfn, error->message );
+		g_error_free( error );
+
+	} else {
+		wdir = na_object_get_working_dir( profile );
+		g_debug( "%s: wdir=%s", thisfn, wdir );
+
+		g_spawn_async( wdir,
+				argv,
+				NULL,
+				G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+				NULL,
+				NULL,
+				&child_pid,
+				&error );
+		if( error ){
+			g_warning( "%s: %s", thisfn, error->message );
+			g_error_free( error );
+		}
+
+		g_spawn_close_pid( child_pid );
+		g_free( wdir );
+		g_strfreev( argv );
+	}
 }
 
 /*
@@ -467,6 +452,7 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
 			case 'd':
 			case 'f':
 			case 'm':
+			case 'o':
 			case 'u':
 			case 'w':
 			case 'x':
@@ -478,6 +464,7 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
 			case 'D':
 			case 'F':
 			case 'M':
+			case 'O':
 			case 'U':
 			case 'W':
 			case 'X':
@@ -502,7 +489,7 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
 }
 
 /*
- * na_tokens_parse_singular:
+ * parse_singular:
  * @tokens: a #NATokens object.
  * @input: the input string, may or may not contain tokens.
  * @i: the number of the iteration in a multiple selection, starting with zero.
@@ -512,12 +499,16 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
  * A command is said of 'singular form' when its first parameter is not
  * of plural form. In the case of a multiple selection, singular form
  * commands are executed one time for each element of the selection
+ *
+ * Returns: a #GSList which contains two fields: the command and its parameters.
+ * The returned #GSList should be na_core_utils_slist_free() by the caller.
  */
 static gchar *
-parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8 )
+parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8, gboolean quoted )
 {
 	GString *output;
-	gchar *iter, *prev_iter, *tmp;
+	gchar *iter, *prev_iter;
+	const gchar *nth;
 
 	output = g_string_new( "" );
 
@@ -548,15 +539,16 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 		switch( iter[1] ){
 			case 'b':
 				if( tokens->private->basenames ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->basenames, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->basenames, i );
+					if( nth ){
+						output = quote_string( output, nth, quoted );
+					}
 				}
 				break;
 
 			case 'B':
 				if( tokens->private->basenames ){
-					output = g_string_append( output, tokens->private->basenames_str );
+					output = quote_string_list( output, tokens->private->basenames, quoted );
 				}
 				break;
 
@@ -566,113 +558,124 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 
 			case 'd':
 				if( tokens->private->basedirs ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->basedirs, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->basedirs, i );
+					if( nth ){
+						output = quote_string( output, nth, quoted );
+					}
 				}
 				break;
 
 			case 'D':
 				if( tokens->private->basedirs ){
-					output = g_string_append( output, tokens->private->basedirs_str );
+					output = quote_string_list( output, tokens->private->basedirs, quoted );
 				}
 				break;
 
 			case 'f':
 				if( tokens->private->filenames ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->filenames, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->filenames, i );
+					if( nth ){
+						output = quote_string( output, nth, quoted );
+					}
 				}
 				break;
 
 			case 'F':
 				if( tokens->private->filenames ){
-					output = g_string_append( output, tokens->private->filenames_str );
+					output = quote_string_list( output, tokens->private->filenames, quoted );
 				}
 				break;
 
 			case 'h':
 				if( tokens->private->hostname ){
-					tmp = g_shell_quote( tokens->private->hostname );
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					output = quote_string( output, tokens->private->hostname, quoted );
 				}
 				break;
 
+			/* mimetypes are never quoted
+			 */
 			case 'm':
 				if( tokens->private->mimetypes ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->mimetypes, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->mimetypes, i );
+					if( nth ){
+						output = quote_string( output, nth, FALSE );
+					}
 				}
 				break;
 
 			case 'M':
 				if( tokens->private->mimetypes ){
-					output = g_string_append( output, tokens->private->mimetypes_str );
+					output = quote_string_list( output, tokens->private->mimetypes, FALSE );
 				}
 				break;
 
+			/* no-op operators */
+			case 'o':
+			case 'O':
+				break;
+
 			case 'n':
 				if( tokens->private->username ){
-					tmp = g_shell_quote( tokens->private->username );
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					output = quote_string( output, tokens->private->username, quoted );
 				}
 				break;
 
+			/* port number is never quoted
+			 */
 			case 'p':
-				g_string_append_printf( output, "%d", tokens->private->port );
+				if( tokens->private->port > 0 ){
+					g_string_append_printf( output, "%d", tokens->private->port );
+				}
 				break;
 
 			case 's':
 				if( tokens->private->scheme ){
-					tmp = g_shell_quote( tokens->private->scheme );
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					output = quote_string( output, tokens->private->scheme, quoted );
 				}
 				break;
 
 			case 'u':
 				if( tokens->private->uris ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->uris, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->uris, i );
+					if( nth ){
+						output = quote_string( output, nth, quoted );
+					}
 				}
 				break;
 
 			case 'U':
 				if( tokens->private->uris ){
-					output = g_string_append( output, tokens->private->uris_str );
+					output = quote_string_list( output, tokens->private->uris, quoted );
 				}
 				break;
 
 			case 'w':
 				if( tokens->private->basenames_woext ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->basenames_woext, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->basenames_woext, i );
+					if( nth ){
+						output = quote_string( output, nth, quoted );
+					}
 				}
 				break;
 
 			case 'W':
 				if( tokens->private->basenames_woext ){
-					output = g_string_append( output, tokens->private->basenames_woext_str );
+					output = quote_string_list( output, tokens->private->basenames_woext, quoted );
 				}
 				break;
 
 			case 'x':
 				if( tokens->private->exts ){
-					tmp = g_shell_quote( g_slist_nth_data( tokens->private->exts, i ));
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					nth = ( const gchar * ) g_slist_nth_data( tokens->private->exts, i );
+					if( nth ){
+						output = quote_string( output, nth, quoted );
+					}
 				}
 				break;
 
 			case 'X':
 				if( tokens->private->exts ){
-					output = g_string_append( output, tokens->private->exts_str );
+					output = quote_string_list( output, tokens->private->exts, quoted );
 				}
 				break;
 
@@ -691,3 +694,44 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 
 	return( g_string_free( output, FALSE ));
 }
+
+static GString *
+quote_string( GString *input, const gchar *name, gboolean quoted )
+{
+	gchar *tmp;
+
+	if( quoted ){
+		tmp = g_shell_quote( name );
+		input = g_string_append( input, tmp );
+		g_free( tmp );
+
+	} else {
+		input = g_string_append( input, name );
+	}
+
+	return( input );
+}
+
+static GString *
+quote_string_list( GString *input, GSList *names, gboolean quoted )
+{
+	GSList *it;
+	gchar *tmp;
+
+	if( quoted ){
+		GSList *quoted_names = NULL;
+		for( it = names ; it ; it = it->next ){
+			quoted_names = g_slist_append( quoted_names, g_shell_quote(( const gchar * ) it->data ));
+		}
+		tmp = na_core_utils_slist_join_at_end( quoted_names, " " );
+		na_core_utils_slist_free( quoted_names );
+
+	} else {
+		tmp = na_core_utils_slist_join_at_end( g_slist_reverse( names ), " " );
+	}
+
+	input = g_string_append( input, tmp );
+	g_free( tmp );
+
+	return( input );
+}
