@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,6 +33,7 @@
 #endif
 
 #include <gio/gio.h>
+#include <libintl.h>
 #include <libxml/tree.h>
 #include <string.h>
 
@@ -99,6 +100,9 @@ static void            instance_init( GTypeInstance *instance, gpointer klass );
 static void            instance_dispose( GObject *object );
 static void            instance_finalize( GObject *object );
 
+static void            write_start_write_type( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup *groups );
+static void            write_start_write_version( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup *groups );
+
 static void            write_data_schema_v1( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxed *boxed, const NADataDef *def );
 static void            write_data_schema_v1_element( NAXMLWriter *writer, const NADataDef *def );
 static void            write_type_schema_v1( NAXMLWriter *writer, const NAObjectItem *object, const NADataDef *def, const gchar *value );
@@ -114,7 +118,6 @@ static xmlDocPtr       build_xml_doc( NAXMLWriter *writer );
 static ExportFormatFn *find_export_format_fn( GQuark format );
 static gchar          *get_output_fname( const NAObjectItem *item, const gchar *folder, GQuark format );
 static void            output_xml_to_file( const gchar *xml, const gchar *filename, GSList **msg );
-static void            write_type( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup *groups );
 static guint           writer_to_buffer( NAXMLWriter *writer );
 
 static ExportFormatFn st_export_format_fn[] = {
@@ -400,12 +403,48 @@ naxml_writer_write_start( const NAIFactoryProvider *provider, void *writer_data,
 		}
 
 		groups = na_ifactory_object_get_data_groups( object );
-		write_type( writer, NA_OBJECT_ITEM( object ), groups );
+		write_start_write_type( writer, NA_OBJECT_ITEM( object ), groups );
+		write_start_write_version( writer, NA_OBJECT_ITEM( object ), groups );
 	}
 
 	return( NA_IIO_PROVIDER_CODE_OK );
 }
 
+/* at end of write_start (list_node already created)
+ * explicitly write the 'Type' node
+ */
+static void
+write_start_write_type( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup *groups )
+{
+	const NADataDef *def;
+	const gchar *svalue;
+
+	writer->private->schema_node = NULL;
+	writer->private->locale_node = NULL;
+	def = na_data_def_get_data_def( groups, NA_FACTORY_OBJECT_ITEM_GROUP, NAFO_DATA_TYPE );
+	svalue = NA_IS_OBJECT_ACTION( object ) ? NAGP_VALUE_TYPE_ACTION : NAGP_VALUE_TYPE_MENU;
+
+	( *writer->private->fn_str->write_type_fn )( writer, object, def, svalue );
+}
+
+static void
+write_start_write_version( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup *groups )
+{
+	const NADataDef *def;
+	guint iversion;
+	gchar *svalue;
+
+	writer->private->schema_node = NULL;
+	writer->private->locale_node = NULL;
+	def = na_data_def_get_data_def( groups, NA_FACTORY_OBJECT_ITEM_GROUP, NAFO_DATA_IVERSION );
+	iversion = na_object_get_iversion( object );
+	svalue = g_strdup_printf( "%d", iversion );
+
+	( *writer->private->fn_str->write_type_fn )( writer, object, def, svalue );
+
+	g_free( svalue );
+}
+
 guint
 naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject *object, const NADataBoxed *boxed, GSList **messages )
 {
@@ -419,7 +458,7 @@ naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
 	/* do no export empty values
 	 */
-	if( na_data_boxed_is_set( boxed ) || def->write_if_default ){
+	if( !na_data_boxed_is_default( boxed ) || def->write_if_default ){
 
 		writer = NAXML_WRITER( writer_data );
 
@@ -455,8 +494,8 @@ write_data_schema_v1_element( NAXMLWriter *writer, const NADataDef *def )
 	}
 
 	xmlNewChild( writer->private->schema_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_OWNER ), BAD_CAST( PACKAGE_TARNAME ));
-	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_SHORT ), BAD_CAST( def->short_label ));
-	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_LONG ), BAD_CAST( def->long_label ));
+	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_SHORT ), BAD_CAST( gettext( def->short_label )));
+	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_LONG ), BAD_CAST( gettext( def->long_label )));
 }
 
 static void
@@ -810,23 +849,6 @@ output_xml_to_file( const gchar *xml, const gchar *filename, GSList **msg )
 	g_object_unref( file );
 }
 
-/* at end of write_start (list_node already created)
- * explicitly write the 'Type' node
- */
-static void
-write_type( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup *groups )
-{
-	const NADataDef *def;
-	const gchar *svalue;
-
-	writer->private->schema_node = NULL;
-	writer->private->locale_node = NULL;
-	def = na_data_def_get_data_def( groups, NA_FACTORY_OBJECT_ITEM_GROUP, NAFO_DATA_TYPE );
-	svalue = NA_IS_OBJECT_ACTION( object ) ? NAGP_VALUE_TYPE_ACTION : NAGP_VALUE_TYPE_MENU;
-
-	( *writer->private->fn_str->write_type_fn )( writer, object, def, svalue );
-}
-
 static guint
 writer_to_buffer( NAXMLWriter *writer )
 {
