@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -695,37 +695,6 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 		}
 	}
 
-	/* import actions
-	 * getting results in the same order than uris
-	 * simultaneously building the actions list
-	 */
-#if 0
-	for( is = uris ; is ; is = is->next ){
-
-		parms.version = 1;
-		parms.uri = ( gchar * ) is->data;
-		parms.mode = mode;
-		parms.window = base_window_get_toplevel( base_application_get_main_window( BASE_APPLICATION( application )));
-		parms.messages = NULL;
-		parms.imported = NULL;
-
-		code = na_importer_import_from_uri( NA_PIVOT( updater ), &parms );
-
-		str = g_new0( ImportUriStruct, 1 );
-		str->uri = g_strdup( parms.uri );
-		str->item = parms.imported;
-		str->msg = na_core_utils_slist_duplicate( parms.messages );
-		na_core_utils_slist_free( parms.messages );
-
-		if( str->item ){
-			na_object_check_status( str->item );
-			imported_items = g_list_prepend( imported_items, str->item );
-		}
-
-		window->private->results = g_slist_prepend( window->private->results, str );
-	}
-#endif
-
 	na_core_utils_slist_free( import_parms.uris );
 	window->private->results = import_parms.results;
 
@@ -760,20 +729,25 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 {
 	static const gchar *thisfn = "nact_assistant_import_prepare_importdone";
 	gchar *text, *tmp, *text2;
-	gchar *bname, *uuid, *label;
+	gchar *bname, *id, *label;
 	GList *is;
 	GSList *im;
 	NAImporterResult *result;
 	GFile *file;
 	guint mode;
-	GtkLabel *summary_label;
+	GtkTextView *summary_textview;
+	GtkTextBuffer *summary_buffer;
+	GtkTextTag *title_tag;
+	GtkTextIter start, end;
+	gint title_len;
 
 	g_debug( "%s: window=%p, assistant=%p, page=%p",
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
 
 	/* i18n: result of the import assistant */
 	text = g_strdup( _( "Selected files have been proceeded :" ));
-	tmp = g_strdup_printf( "<b>%s</b>\n\n", text );
+	title_len = g_utf8_strlen( text, -1 );
+	tmp = g_strdup_printf( "%s\n\n", text );
 	g_free( text );
 	text = tmp;
 
@@ -793,12 +767,12 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 			tmp = g_strdup_printf( "%s\t\t%s\n", text, _( "Import OK" ));
 			g_free( text );
 			text = tmp;
-			uuid = na_object_get_id( result->imported );
+			id = na_object_get_id( result->imported );
 			label = na_object_get_label( result->imported );
 			/* i18n: this is the globally unique identifier and the label of the newly imported action */
-			text2 = g_strdup_printf( _( "UUID: %s\t%s" ), uuid, label);
+			text2 = g_strdup_printf( _( "Id.: %s\t%s" ), id, label);
 			g_free( label );
-			g_free( uuid );
+			g_free( id );
 			tmp = g_strdup_printf( "%s\t\t%s\n", text, text2 );
 			g_free( text );
 			text = tmp;
@@ -823,10 +797,21 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 		text = tmp;
 	}
 
-	summary_label = GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "AssistantImportSummaryLabel" ));
-	gtk_label_set_markup( summary_label, text );
+	summary_textview = GTK_TEXT_VIEW( base_window_get_widget( BASE_WINDOW( window ), "AssistantImportSummaryTextView" ));
+	summary_buffer = gtk_text_view_get_buffer( summary_textview );
+	gtk_text_buffer_set_text( summary_buffer, text, -1 );
 	g_free( text );
 
+	title_tag = gtk_text_buffer_create_tag( summary_buffer, "title",
+			"weight", PANGO_WEIGHT_BOLD,
+			NULL );
+
+	gtk_text_buffer_get_iter_at_offset( summary_buffer, &start, 0 );
+	gtk_text_buffer_get_iter_at_offset( summary_buffer, &end, title_len );
+	gtk_text_buffer_apply_tag( summary_buffer, title_tag, &start, &end );
+
+	g_object_unref( title_tag );
+
 	mode = get_import_mode( window );
 	na_iprefs_set_import_mode( window->private->gconf, IPREFS_IMPORT_ITEMS_IMPORT_MODE, mode );
 
