@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -58,7 +58,7 @@ typedef gboolean ( *FnIterOnSelection )( NactIActionsList *, GtkTreeView *, GtkT
  */
 typedef struct {
 	NAObject *object;
-	gchar    *uuid;
+	gchar    *id;
 }
 	IdToObjectIter;
 
@@ -289,7 +289,7 @@ nact_iactions_list_bis_get_item( NactIActionsList *instance, const gchar *id )
 		model = NACT_TREE_MODEL( gtk_tree_view_get_model( treeview ));
 
 		ito = g_new0( IdToObjectIter, 1 );
-		ito->uuid = ( gchar * ) id;
+		ito->id = ( gchar * ) id;
 
 		nact_tree_model_iter( model, ( FnIterOnStore ) get_item_iter, ito );
 
@@ -909,7 +909,7 @@ get_item_iter( NactTreeModel *model, GtkTreePath *path, NAObject *object, IdToOb
 	gboolean found = FALSE;
 
 	id = na_object_get_id( object );
-	found = ( g_ascii_strcasecmp( id, ito->uuid ) == 0 );
+	found = ( g_ascii_strcasecmp( id, ito->id ) == 0 );
 	g_free( id );
 
 	if( found ){
