@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,6 +33,7 @@
 #endif
 
 #include <glib/gi18n.h>
+#include <libintl.h>
 
 #include <api/na-core-utils.h>
 
@@ -313,9 +314,9 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
 		if( g_slist_length( messages )){
 			msg = na_core_utils_slist_join_at_end( messages, "\n" );
 		} else {
-			msg = g_strdup( st_level_zero_write );
+			msg = g_strdup( gettext( st_level_zero_write ));
 		}
-		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_ERROR, st_save_error, msg );
+		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_ERROR, gettext( st_save_error ), msg );
 		g_free( msg );
 		na_core_utils_slist_free( messages );
 		return;
@@ -331,9 +332,9 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
 		if( g_slist_length( messages )){
 			msg = na_core_utils_slist_join_at_end( messages, "\n" );
 		} else {
-			msg = g_strdup( st_delete_error );
+			msg = g_strdup( gettext( st_delete_error ));
 		}
-		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_ERROR, st_save_error, msg );
+		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_ERROR, gettext( st_save_error ), msg );
 		g_free( msg );
 		na_core_utils_slist_free( messages );
 		return;
@@ -366,7 +367,7 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
 
 	if( g_slist_length( messages )){
 		msg = na_core_utils_slist_join_at_end( messages, "\n" );
-		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_WARNING, st_save_warning, msg );
+		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_WARNING, gettext( st_save_warning ), msg );
 		g_free( msg );
 		na_core_utils_slist_free( messages );
 	}
