@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,7 +33,6 @@
 #endif
 
 #include <gconf/gconf-client.h>
-#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
 #include <api/na-core-utils.h>
@@ -41,6 +40,7 @@
 
 #include <core/na-iprefs.h>
 
+#include "base-keysyms.h"
 #include "nact-application.h"
 #include "nact-gtk-utils.h"
 #include "nact-main-tab.h"
@@ -142,7 +142,7 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
 	gtk_tree_sortable_set_sort_column_id( GTK_TREE_SORTABLE( model ), SCHEMES_KEYWORD_COLUMN, GTK_SORT_ASCENDING );
 	gtk_tree_view_column_set_cell_data_func(
 			column, text_cell, ( GtkTreeCellDataFunc ) display_keyword, data, NULL );
-	nact_gtk_utils_set_editable( GTK_OBJECT( column ), mode == SCHEMES_LIST_FOR_PREFERENCES );
+	nact_gtk_utils_set_editable( G_OBJECT( column ), mode == SCHEMES_LIST_FOR_PREFERENCES );
 
 	text_cell = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes(
@@ -153,7 +153,7 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
 	gtk_tree_view_append_column( treeview, column );
 	gtk_tree_view_column_set_cell_data_func(
 			column, text_cell, ( GtkTreeCellDataFunc ) display_description, data, NULL );
-	nact_gtk_utils_set_editable( GTK_OBJECT( column ), mode == SCHEMES_LIST_FOR_PREFERENCES );
+	nact_gtk_utils_set_editable( G_OBJECT( column ), mode == SCHEMES_LIST_FOR_PREFERENCES );
 
 	gtk_tree_view_set_headers_visible( treeview, FALSE );
 
@@ -394,7 +394,7 @@ nact_schemes_list_show_all( BaseWindow *window )
 	data = get_schemes_list_data( listview );
 
 	button = get_add_button( window );
-#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 18 ))
+#if GTK_CHECK_VERSION( 2, 18, 0 )
 	gtk_widget_set_visible( GTK_WIDGET( button ), data->mode == SCHEMES_LIST_FOR_PREFERENCES );
 #else
 	if( data->mode == SCHEMES_LIST_FOR_PREFERENCES ){
@@ -406,7 +406,7 @@ nact_schemes_list_show_all( BaseWindow *window )
 	gtk_widget_set_sensitive( GTK_WIDGET( button ), data->mode == SCHEMES_LIST_FOR_PREFERENCES );
 
 	button = get_remove_button( window );
-#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 18 ))
+#if GTK_CHECK_VERSION( 2, 18, 0 )
 	gtk_widget_set_visible( GTK_WIDGET( button ), data->mode == SCHEMES_LIST_FOR_PREFERENCES );
 #else
 	if( data->mode == SCHEMES_LIST_FOR_PREFERENCES ){
@@ -539,17 +539,17 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, BaseWindow *window
 
 	stop = FALSE;
 
-	if( event->keyval == GDK_F2 ){
+	if( event->keyval == NACT_KEY_F2 ){
 		edit_inline( window );
 		stop = TRUE;
 	}
 
-	if( event->keyval == GDK_Insert || event->keyval == GDK_KP_Insert ){
+	if( event->keyval == NACT_KEY_Insert || event->keyval == NACT_KEY_KP_Insert ){
 		insert_new_row( window );
 		stop = TRUE;
 	}
 
-	if( event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete ){
+	if( event->keyval == NACT_KEY_Delete || event->keyval == NACT_KEY_KP_Delete ){
 		delete_row( window );
 		stop = TRUE;
 	}
