@@ -34,6 +34,7 @@
 
 #include <gconf/gconf-client.h>
 #include <glib/gi18n.h>
+#include <libintl.h>
 #include <string.h>
 
 #include <api/na-core-utils.h>
@@ -172,7 +173,10 @@ nact_tree_model_dnd_idrag_dest_drag_data_received( GtkTreeDragDest *drag_dest, G
 	g_debug( "%s: drag_dest=%p, dest=%p, selection_data=%p", thisfn, ( void * ) drag_dest, ( void * ) dest, ( void * ) selection_data );
 	g_return_val_if_fail( NACT_IS_TREE_MODEL( drag_dest ), FALSE );
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 14 ) || GTK_MAJOR_VERSION >= 3 )
+/* gtk_selection_data_get_data() appears with Gtk+ 2.14.0 release on 2008-09-04
+ * see http://git.gnome.org/browse/gtk+/commit/?id=9eae7a1d2e7457d67ba00bb8c35775c1523fa186
+ */
+#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_selection = gtk_selection_data_get_selection( selection_data );
 #else
 	selection_data_selection = selection_data->selection;
@@ -181,7 +185,7 @@ nact_tree_model_dnd_idrag_dest_drag_data_received( GtkTreeDragDest *drag_dest, G
 	g_debug( "%s: selection=%s", thisfn, atom_name );
 	g_free( atom_name );
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 14 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_target = gtk_selection_data_get_target( selection_data );
 #else
 	selection_data_target = selection_data->target;
@@ -190,7 +194,7 @@ nact_tree_model_dnd_idrag_dest_drag_data_received( GtkTreeDragDest *drag_dest, G
 	g_debug( "%s: target=%s", thisfn, atom_name );
 	g_free( atom_name );
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 14 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_type = gtk_selection_data_get_data_type( selection_data );
 #else
 	selection_data_type = selection_data->type;
@@ -199,7 +203,7 @@ nact_tree_model_dnd_idrag_dest_drag_data_received( GtkTreeDragDest *drag_dest, G
 	g_debug( "%s: type=%s", thisfn, atom_name );
 	g_free( atom_name );
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 14 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_format = gtk_selection_data_get_format( selection_data );
 	selection_data_length = gtk_selection_data_get_length( selection_data );
 #else
@@ -307,13 +311,13 @@ nact_tree_model_dnd_imulti_drag_source_drag_data_get( EggTreeMultiDragSource *dr
 	GdkDragAction context_suggested_action;
 	GdkDragAction context_selected_action;
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 14 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_target = gtk_selection_data_get_target( selection_data );
 #else
 	selection_data_target = selection_data->target;
 #endif
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 22 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 22, 0 )
 	context_suggested_action = gdk_drag_context_get_suggested_action( context );
 	context_selected_action = gdk_drag_context_get_selected_action( context );
 #else
@@ -499,7 +503,7 @@ nact_tree_model_dnd_on_drag_begin( GtkWidget *widget, GdkDragContext *context, B
 
 		nact_clipboard_dnd_clear( model->private->clipboard );
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 22 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 22, 0 )
 		context_source_window = gdk_drag_context_get_source_window( context );
 #else
 		context_source_window = context->source_window;
@@ -535,7 +539,7 @@ nact_tree_model_dnd_on_drag_end( GtkWidget *widget, GdkDragContext *context, Bas
 		nact_clipboard_dnd_drag_end( model->private->clipboard );
 		nact_clipboard_dnd_clear( model->private->clipboard );
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 22 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 22, 0 )
 		context_source_window = gdk_drag_context_get_source_window( context );
 #else
 		context_source_window = context->source_window;
@@ -690,7 +694,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, NAObjectItem **parent
 
 		if( model->private->drag_has_profiles ){
 			nact_main_statusbar_display_with_timeout(
-						main_window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_profile );
+						main_window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
 
 		} else {
 			drop_ok = TRUE;
@@ -738,7 +742,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, NactMainW
 		} else {
 			/* unable to drop a profile here */
 			nact_main_statusbar_display_with_timeout(
-					window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_profile );
+					window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
 		}
 
 	} else if( NA_IS_OBJECT_ITEM( object )){
@@ -748,7 +752,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, NactMainW
 	} else {
 		/* unable to drop an action or a menu here */
 		nact_main_statusbar_display_with_timeout(
-				window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_item );
+				window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_item ));
 	}
 
 	return( drop_ok );
@@ -782,7 +786,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, NactMainWin
 
 				} else {
 					nact_main_statusbar_display_with_timeout(
-							window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_profile );
+							window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
 				}
 
 			} else if( NA_IS_OBJECT_MENU( object )){
@@ -791,7 +795,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, NactMainWin
 
 			} else {
 				nact_main_statusbar_display_with_timeout(
-						window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_item );
+						window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_item ));
 			}
 		}
 	}
@@ -883,7 +887,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	updater = nact_application_get_updater( application );
 	main_window = NACT_MAIN_WINDOW( base_application_get_main_window( BASE_APPLICATION( application )));
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 14 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_data = ( const gchar * ) gtk_selection_data_get_data( selection_data );
 #else
 	selection_data_data = ( const gchar * ) selection_data->data;
@@ -1094,7 +1098,7 @@ get_xds_atom_value( GdkDragContext *context )
 	gint actual_length;
 	GdkWindow *context_source_window;
 
-#if(( GTK_MAJOR_VERSION >= 2 && GTK_MINOR_VERSION >= 22 ) || GTK_MAJOR_VERSION >= 3 )
+#if GTK_CHECK_VERSION( 2, 22, 0 )
 		context_source_window = gdk_drag_context_get_source_window( context );
 #else
 		context_source_window = context->source_window;
@@ -1142,7 +1146,7 @@ is_parent_accept_new_childs( NactApplication *application, NactMainWindow *windo
 
 		} else {
 			nact_main_statusbar_display_with_timeout(
-						window, TREE_MODEL_STATUSBAR_CONTEXT, st_level_zero_not_writable );
+						window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_level_zero_not_writable ));
 		}
 
 	/* see if the parent is writable
@@ -1152,7 +1156,7 @@ is_parent_accept_new_childs( NactApplication *application, NactMainWindow *windo
 
 	} else {
 			nact_main_statusbar_display_with_timeout(
-						window, TREE_MODEL_STATUSBAR_CONTEXT, st_parent_not_writable );
+						window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_parent_not_writable ));
 	}
 
 	return( accept_ok );
